load

Function load 

pub fn load() -> Result<IjimaToml>
Loads and parses the config file, if any exists.

Errors

  • IjimaError::InvalidInput if an existing file cannot be read or parsed (including an explicit $IJIMA_CONFIG pointing at a missing file — an explicit pointer must be honored, not silently skipped).