pub fn init_tracing()Expand description
Initializes structured logging (tracing) if not already installed.
Idempotent — safe to call from both the daemon and CLI paths.
pub fn init_tracing()Initializes structured logging (tracing) if not already installed.
Idempotent — safe to call from both the daemon and CLI paths.