pub fn load() -> Result<IjimaToml>Expand description
Loads and parses the config file, if any exists.
Errors
IjimaError::InvalidInputif an existing file cannot be read or parsed (including an explicit$IJIMA_CONFIGpointing at a missing file — an explicit pointer must be honored, not silently skipped).